@@ -50,7 +50,7 @@ def write_xml(filename, desktop_files, light_ind, show_all_apps, multi_ind,
               panel_change_color, dock_panel_change_only, use_panel_act_list,
               active_icon_bg, fallback_bar_col, spacing, attention_type,
               popup_delay, saved_configs, pa_on_all_ws, dock_fixed_size,
-              click_action):
+              click_action, theme):
     """ Write the xml file using the specified information
 
     The xml file will be in e.g. the following format:
@@ -121,6 +121,7 @@ def write_xml(filename, desktop_files, light_ind, show_all_apps, multi_ind,
 
         dock_fixed_size : the fixed size (if any) that the dock is to maintain
         click_action : what the applet does when a running app's icon is clicked
+        theme : int - the theme used by the dock
 
     Returns:
         Boolean - True if the file was written successfully, False otherwise
@@ -176,9 +177,11 @@ def write_xml(filename, desktop_files, light_ind, show_all_apps, multi_ind,
 
     paoaws_el = ET.Element("pinned_apps_all_workspaces", paoaws="%s" % pa_on_all_ws)
 
-    dfs_el = ET.Element("dock_fixed_size", dfs="%d" %dock_fixed_size)
+    dfs_el = ET.Element("dock_fixed_size", dfs="%d" % dock_fixed_size)
 
-    ct_el = ET.Element("click_action", ca="%d" %click_action)
+    ct_el = ET.Element("click_action", ca="%d" % click_action)
+
+    theme_el = ET.Element("theme", id="%d" % theme)
 
     root.append(pa_el)
     root.append(ind_el)
@@ -198,6 +201,7 @@ def write_xml(filename, desktop_files, light_ind, show_all_apps, multi_ind,
     root.append(paoaws_el)
     root.append(dfs_el)
     root.append(ct_el)
+    root.append(theme_el)
 
     try:
         ET.ElementTree(root).write(filename, xml_declaration=True)
@@ -237,7 +241,7 @@ def read_xml(filename):
             a boolean - the pinned apps on all workspaces setting
             an int    - the fixed size (if any) of the dock
             an int    - the type of action to perform when a running app's icon is clicked
-
+            an int    - the theme being useed by the dock
     """
 
     try:
@@ -377,12 +381,19 @@ def read_xml(filename):
     else:
         click_action = 0
 
+    theme_el = root.find("theme")
+    if theme_el is not None:
+        theme = int(theme_el.get("id"))
+    else:
+        theme = 0
+
     return [True, df_list, light_ind, show_all, multi_ind,
             use_win_list, win_from_cur_ws_only,
             panel_change_color, dock_panel_change_only,
             use_panel_act_list, bg_type, fallback_bar_col,
             spacing, attention_type, popup_delay, saved_configs,
-            pinned_apps_all_workspaces, dock_fixed_size, click_action]
+            pinned_apps_all_workspaces, dock_fixed_size, click_action,
+            theme]
 
 
 def read_app_xml(filename):
